import express, { Request, Response } from "express";
import bodyParser from 'body-parser';
import { env } from 'node:process';
import { processPayments } from "./routes/payment.js";

const app = express();
const port = 3000;

const processor: string = env.NUCLEUS_PROCESSOR || 'undefined'

const jsonParser = bodyParser.json({
  limit: env.NUCLEUS_JSONPARSER_LIMIT || '100kb',
  strict: true
})

app.enable('trust proxy');
app.disable('x-powered-by');
app.set('etag', false);

app.get('/{*splat}', (req: Request, res: Response) => {
  res.setHeader("Cache-Control", "public, max-age=14400");
  res.sendStatus(200);
});

app.options('/{*splat}', (req: Request, res: Response) => {
  res.setHeader("Access-Control-Allow-Methods", "POST");
  res.setHeader("Access-Control-Allow-Headers", "Content-Type");
  res.setHeader("Access-Control-Max-Age", "3600");
  res.sendStatus(204);
})

app.post(`/${processor}`, jsonParser, async (req: Request, res: Response) => {
  res.setHeader("Access-Control-Allow-Origin", "*");
  await processPayments(req.body, processor)
  res.sendStatus(201);
})

const server = app.listen(port, () => {
  console.log('Serving function...');
});

function shutdown(signal: string) {
  console.log(`Received ${signal}. Shutting down gracefully...`);
  
  server.close(() => {
    console.log('HTTP server closed.');
    process.exit(0);
  });

  setTimeout(() => {
    console.error('Forced shutdown due to timeout.');
    process.exit(1);
  }, 10000);
}

process.on('SIGTERM', () => shutdown('SIGTERM'));
process.on('SIGINT', () => shutdown('SIGINT')); // Handles Ctrl+C
