import countryCodes from 'country-codes-list'
import { env } from 'node:process';
import { createDirectus, rest, staticToken, createItem } from '@directus/sdk';

/**
 * Process Payments
 *
 * @param event The payment event
 * @param processor The processor name
 * @returns A void promise
 */
export async function processPayments(
  event:any,
  processor: string
): Promise<void> {

  const url: string = env.NUCLEUS_DIRECTUS_API || 'undefined'
  const access_token: string = env.NUCLEUS_DIRECTUS_TOKEN || 'undefined'
  const collection: string = env.NUCLEUS_DIRECTUS_COLLECTION || 'undefined'
  const directus = createDirectus(url)
    .with(staticToken(access_token))
    .with(rest());
    
  switch (event.type) {
    case 'checkout.session.completed':
      const checkout: any = event.data.object;

      let completeName: string[] = checkout.customer_details.name.split(' ');
      if (completeName[1] == null ){
      completeName[1] = completeName[0];
      };

      const countries: any = countryCodes.customList('countryCode', '{countryNameLocal}');
      
      directus.request(
        createItem(collection, {
          first_name: completeName[0],
          last_name: completeName[1],
          email: checkout.customer_details.email,
          country: countries[checkout.customer_details.address.country],
          mobile: checkout.customer_details.phone,
          product: checkout.metadata.SKU,
          tags: [processor]
        })
      );
    };
}
